// notify.hpp

#ifndef NOTIFY_H_
#define NOTIFY_H_

#include <cstdint>
#include <memory>
#include <string_view>

namespace notify {

enum class DialogIcon : std::uint8_t { Error, Warning, Info, Question, Password };
enum class BackendType : std::uint8_t { Libnotify, Console };

struct NotifyInterface;

template <BackendType Backend>
class Notification {
   public:
	explicit Notification(std::string_view app_name);
	~Notification();

	Notification(Notification const&) = delete;
	auto operator=(Notification const&) -> Notification& = delete;
	Notification(Notification&&) noexcept;
	auto operator=(Notification&&) noexcept -> Notification&;

	auto show(std::string_view title, std::string_view message, DialogIcon icon) -> bool;
	[[nodiscard]] auto error_message() const -> std::string_view;

   private:
	std::unique_ptr<NotifyInterface> impl_;
};

}  // namespace notify

#endif	// NOTIFY_H_
